"""
Django settings for codeschool project.

Generated by 'django-admin startproject' using Django 1.9.2.

For more information on this file, see
https://docs.djangoproject.com/en/1.9/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.9/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os

# ./codeschool/src/codeschool
CODESCHOOL_APP_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# ./codeschool/src/
SOURCE_FOLDER_DIR = os.path.dirname(CODESCHOOL_APP_DIR)

# ./codeschool
PROJECT_DIR = os.path.dirname(SOURCE_FOLDER_DIR)


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.9/howto/deployment/checklist/


# Application definition

INSTALLED_APPS = [
    # Local apps
    'cs_pages',
    'cs_search',
    'cs_auth',
    'cs_courses',
    'cs_questions',
    'cs_activities',
    'cs_linktable',

    # Wagtail and dependencies
    'wagtail.wagtailforms',
    'wagtail.wagtailredirects',
    'wagtail.wagtailembeds',
    'wagtail.wagtailsites',
    'wagtail.wagtailusers',
    'wagtail.wagtailsnippets',
    'wagtail.wagtaildocs',
    'wagtail.wagtailimages',
    'wagtail.wagtailsearch',
    'wagtail.wagtailadmin',
    'wagtail.wagtailcore',
    'modelcluster',
    'compressor',
    'taggit',

    # 3rd party
    'annoying',
    'djangobower',
    'django_jinja',
    #'debug_toolbar',
    'django_extensions',
    'guardian',

    # Django
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
]

MIDDLEWARE_CLASSES = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',

    'wagtail.wagtailcore.middleware.SiteMiddleware',
    'wagtail.wagtailredirects.middleware.RedirectMiddleware',
]


# Authentication backends

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',
    'guardian.backends.ObjectPermissionBackend',
)


ROOT_URLCONF = 'codeschool.urls'

TEMPLATES = [
    {
        # 'BACKEND': 'django.template.backends.jinja2.Jinja2',
        'BACKEND': 'django_jinja.backend.Jinja2',
        'APP_DIRS': True,
        'DIRS': [
            os.path.join(CODESCHOOL_APP_DIR, 'templates'),
        ],
        'OPTIONS': {
            "match_extension": ".jinja2",
            "autoescape": False,
            'extensions': [
                "jinja2.ext.do",
                "jinja2.ext.loopcontrols",
                "jinja2.ext.with_",
                "jinja2.ext.i18n",
                "jinja2.ext.autoescape",
                "django_jinja.builtins.extensions.CsrfExtension",
                "django_jinja.builtins.extensions.CacheExtension",
                "django_jinja.builtins.extensions.TimezoneExtension",
                "django_jinja.builtins.extensions.UrlsExtension",
                "django_jinja.builtins.extensions.StaticFilesExtension",
                "django_jinja.builtins.extensions.DjangoFiltersExtension",
                'wagtail.wagtailcore.jinja2tags.core',
                'wagtail.wagtailadmin.jinja2tags.userbar',
                'wagtail.wagtailimages.jinja2tags.images',
            ],
            "context_processors": [
                "django.contrib.auth.context_processors.auth",
                "django.template.context_processors.debug",
                "django.template.context_processors.i18n",
                "django.template.context_processors.media",
                "django.template.context_processors.static",
                "django.template.context_processors.tz",
                "django.contrib.messages.context_processors.messages",
            ],
            "filters": {
                'markdown': 'codeschool.filters.markdown',
            }
        }
    },

    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(CODESCHOOL_APP_DIR, 'templates'),
        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

JINJA_ENVIRONMENT = {
    'trim_blocks': True,
    'lstrip_blocks': True,
}


WSGI_APPLICATION = 'codeschool.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.9/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(SOURCE_FOLDER_DIR, 'db.sqlite3'),
    }
}


# Internationalization
# https://docs.djangoproject.com/en/1.9/topics/i18n/

LANGUAGE_CODE = 'pt-BR'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True
USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.9/howto/static-files/

STATICFILES_FINDERS = [
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'compressor.finders.CompressorFinder',
    'djangobower.finders.BowerFinder',
]

STATICFILES_DIRS = [
    os.path.join(CODESCHOOL_APP_DIR, 'static'),
    os.path.join(CODESCHOOL_APP_DIR, 'bower'),
]

STATIC_ROOT = os.path.join(PROJECT_DIR, 'collect', 'static')
STATIC_URL = '/static/'

MEDIA_ROOT = os.path.join(PROJECT_DIR, 'collect', 'media')
MEDIA_URL = '/media/'


# Bower applications

BOWER_COMPONENTS_ROOT = os.path.join(CODESCHOOL_APP_DIR, 'bower/')
BOWER_INSTALLED_APPS = [
    'jquery',
    'mustache',
    'normalize.css',
    'codemirror',
    'highlight',

    # Styling
    #'font-roboto#^1.0.1',

    # All polymer dependencies
    'Polymer/polymer',
    'PolymerElements/gold-cc-cvc-input',
    'PolymerElements/gold-cc-expiration-input',
    'PolymerElements/gold-cc-input',
    'PolymerElements/gold-email-input',
    'PolymerElements/gold-phone-input',
    'PolymerElements/gold-zip-input',
    'PolymerElements/iron-a11y-announcer',
    'PolymerElements/iron-a11y-keys',
    'PolymerElements/iron-a11y-keys-behavior',
    'PolymerElements/iron-ajax',
    'PolymerElements/iron-autogrow-textarea',
    'PolymerElements/iron-behaviors',
    'PolymerElements/iron-checked-element-behavior',
    'PolymerElements/iron-collapse',
    'PolymerElements/iron-component-page',
    'PolymerElements/iron-doc-viewer',
    'PolymerElements/iron-dropdown',
    'PolymerElements/iron-elements',
    'PolymerElements/iron-fit-behavior',
    'PolymerElements/iron-flex-layout',
    'PolymerElements/iron-form',
    'PolymerElements/iron-form-element-behavior',
    'PolymerElements/iron-icon',
    'PolymerElements/iron-icons',
    'PolymerElements/iron-iconset',
    'PolymerElements/iron-iconset-svg',
    'PolymerElements/iron-image',
    'PolymerElements/iron-input',
    'PolymerElements/iron-jsonp-library',
    'PolymerElements/iron-list',
    'PolymerElements/iron-localstorage',
    'PolymerElements/iron-media-query',
    'PolymerElements/iron-menu-behavior',
    'PolymerElements/iron-meta',
    'PolymerElements/iron-overlay-behavior',
    'PolymerElements/iron-pages',
    'PolymerElements/iron-range-behavior',
    'PolymerElements/iron-resizable-behavior',
    'PolymerElements/iron-selector',
    'PolymerElements/iron-signals',
    'PolymerElements/iron-test-helpers',
    'PolymerElements/iron-validatable-behavior',
    'PolymerElements/iron-validator-behavior',
    'PolymerElements/neon-animation',
    'PolymerElements/neon-elements',
    'PolymerElements/paper-badge',
    'PolymerElements/paper-behaviors',
    'PolymerElements/paper-button',
    'PolymerElements/paper-card',
    'PolymerElements/paper-checkbox',
    'PolymerElements/paper-dialog',
    'PolymerElements/paper-dialog-behavior',
    'PolymerElements/paper-dialog-scrollable',
    'PolymerElements/paper-drawer-panel',
    'PolymerElements/paper-dropdown-menu',
    'PolymerElements/paper-elements',
    'PolymerElements/paper-fab',
    'PolymerElements/paper-header-panel',
    'PolymerElements/paper-icon-button',
    'PolymerElements/paper-input',
    'PolymerElements/paper-item',
    'PolymerElements/paper-listbox',
    'PolymerElements/paper-material',
    'PolymerElements/paper-menu',
    'PolymerElements/paper-menu-button',
    'PolymerElements/paper-progress',
    'PolymerElements/paper-radio-button',
    'PolymerElements/paper-radio-group',
    'PolymerElements/paper-ripple',
    'PolymerElements/paper-scroll-header-panel',
    'PolymerElements/paper-slider',
    'PolymerElements/paper-spinner',
    'PolymerElements/paper-styles',
    'PolymerElements/paper-tabs',
    'PolymerElements/paper-toast',
    'PolymerElements/paper-toggle-button',
    'PolymerElements/paper-toolbar',
    'PolymerElements/paper-tooltip',
    'PolymerElements/platinum-bluetooth',
    'PolymerElements/platinum-elements',
    'PolymerElements/platinum-https-redirect',
    'PolymerElements/platinum-push-messaging',
    'PolymerElements/platinum-sw',
]


# Wagtail settings

WAGTAIL_SITE_NAME = "codeschool"
